@@ -9,3 +9,5 @@ test_check('monotonicity', filter = "monoSummary")
 test_check('monotonicity', filter = "monoUpDown")
 test_check('monotonicity', filter = "specify_decimal")
 test_check('monotonicity', filter = "wolak")
+test_check('monotonicity', filter = "matrix_conversion")
+test_check('monotonicity', filter = "statBootstrap")
