@@ -1,6 +1,9 @@
 context('functions')
 
 test_that('monoBonferroni', {
+  
+  expect_error(monoBonferroni(difference = FALSE))
+  expect_error(monoBonferroni(demo_returns, difference = "FALSE"))
 
   tmp <- monoBonferroni(demo_returns, difference = FALSE)
 
